/**************************************************************************//**
*   @file   ADF4106.h
*   @brief  Header file of ADF4106 Driver for Nios II processor.
*   @author ATofan (alexandru.tofan@analog.com)
*
*******************************************************************************
* Copyright 2011(c) Analog Devices, Inc.
*
* All rights reserved.
*
* Redistribution and use in source and binary forms, with or without modification,
* are permitted provided that the following conditions are met:
*  - Redistributions of source code must retain the above copyright
*    notice, this list of conditions and the following disclaimer.
*  - Redistributions in binary form must reproduce the above copyright
*    notice, this list of conditions and the following disclaimer in
*    the documentation and/or other materials provided with the
*    distribution.
*  - Neither the name of Analog Devices, Inc. nor the names of its
*    contributors may be used to endorse or promote products derived
*    from this software without specific prior written permission.
*  - The use of this software may or may not infringe the patent rights
*    of one or more patent holders.  This license does not release you
*    from the requirement that you obtain separate licenses from these
*    patent holders to use this software.
*  - Use of the software either in source or binary form, must be run
*    on or directly connected to an Analog Devices Inc. component.
*
* THIS SOFTWARE IS PROVIDED BY ANALOG DEVICES "AS IS" AND ANY EXPRESS OR IMPLIED
* WARRANTIES, INCLUDING, BUT NOT LIMITED TO, NON-INFRINGEMENT, MERCHANTABILITY
* AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
* IN NO EVENT SHALL ANALOG DEVICES BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
* SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
* INTELLECTUAL PROPERTY RIGHTS, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
* LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
* ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
* (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
* SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*
*******************************************************************************
*   SVN Revision: 468
******************************************************************************/
#ifndef _ADF4106_H_
#define _ADF4106_H_
#ifdef ADF4106_GLOBALS
	#define ADF4106_EXT extern volatile
#else
	#define ADF4106_EXT volatile
#endif

/*****************************************************************************/
/* Include Files                                                             */
/*****************************************************************************/
#include "adi.h"

#if(USE_ADF4106 == 1)
/*****************************************************************************/
/* SPI Configuration                                                         */
/*****************************************************************************/
#define ADF4106_SPI		SPI_0_P0_BASE
#define ADF4106_SPI_CFG	(SPI0_ena)

/*****************************************************************************/
/* Register description                                                      */
/*****************************************************************************/
// [1:0] Command Bits
#define ADF4106_RCounter		0
#define ADF4106_NCounter		1
#define ADF4106_Function		2
#define ADF4106_cmdInit			3

// Reference Counter Latch [1:0] = 00
#define ADF4106_LDP				20
#define ADF4106_ABP2			17
#define ADF4106_ABP1			16
#define ADF4106_RValue			2

// N Counter Latch [1:0] = 01
#define ADF4106_CPGain			21
#define ADF4106_BValue			8
#define ADF4106_AValue			2

// Function Latch [1:0] = 10
// Initialization Latch [1:0] = 11
#define ADF4106_Prescaler		22
#define ADF4106_PowerDown2		21
#define ADF4106_CurrentSetting2	18
#define ADF4106_CurrentSetting1	15
#define ADF4106_TimerControl	11
#define ADF4106_FastlockMode	10
#define ADF4106_FastlockEn		9
#define ADF4106_CPThreeState	8
#define ADF4106_PDPolarity		7
#define ADF4106_Muxout			4
#define ADF4106_PowerDown1		3
#define ADF4106_CounterRst		2

ADF4106_EXT uCProbeDataUnion ADF4106_Data[22];
#endif
int ADF4106_Init(void);
int ADF4106_UpdateParameters(void);
#endif
